from installclass import BaseInstallClass
import rhpl
from rhpl.translate import N_,_
from constants import *
import os
import iutil
import types
try:
    import instnum
except ImportError:
    instnum = None

import logging
log = logging.getLogger("anaconda")

# custom installs are easy :-)
class InstallClass(BaseInstallClass):
    # name has underscore used for mnemonics, strip if you dont need it
    id = "centos"
    name = N_("CentOS Linux")
    description = N_("The default installation of %s includes a set of "
                     "software applicable for general internet usage. "
                     "What additional tasks would you like your system "
                     "to include support for?") %(productName,)
    sortPriority = 10000
    allowExtraRepos = True
    if 0: # not productName.startswith("Red Hat Enterprise"):
        hidden = 1

    tasks = [(N_("Desktop - Gnome "), ["graphics", "office", "games", "sound-and-video","base-x","gnome-desktop","graphical-internet","printing"]),
             (N_("Desktop - KDE "), ["graphics", "office", "games", "sound-and-video","base-x","kde-desktop","graphical-internet","printing"]),
              (N_("Server "), ["server-cfg", "dns-server", "web-server", "ftp-server", "smb-server", "mail-server", "network-server", "legacy-network-server", "news-server"]),
              (N_("Server - GUI "), ["server-cfg", "dns-server", "web-server", "ftp-server", "smb-server", "mail-server", "network-server", "legacy-network-server", "news-server", "base-x", "gnome-desktop", "admin-tools"])]

    instkeyname = _("Installation Number")
    instkeydesc = _("To install the full set of supported packages included "
                    "Number")
    skipkeytext = _("If you're unable to locate the Installation Number, "
                    "for packages not included in your subscription.")
 

    def setInstallData(self, anaconda):
	BaseInstallClass.setInstallData(self, anaconda)
        BaseInstallClass.setDefaultPartitioning(self, anaconda.id.partitions,
                                                CLEARPART_TYPE_LINUX)

    def setGroupSelection(self, anaconda):
        grps = anaconda.backend.getDefaultGroups()
        map(lambda x: anaconda.backend.selectGroup(x), grps)
        coregrps = ["core", "base", "dialup", "text-internet"]
        map(lambda x: anaconda.backend.selectGroup(x), coregrps)
        desktopgrps = ["editors", "graphics", "office", "games", "sound-and-video","base-x","gnome-desktop","graphical-internet","printing"]
        map(lambda x: anaconda.backend.selectGroup(x), desktopgrps)



    def setSteps(self, dispatch):
	BaseInstallClass.setSteps(self, dispatch);
	dispatch.skipStep("partition")
	dispatch.skipStep("regkey", skip = 0)        

    # for rhel, we're putting the metadata under productpath

    def handleRegKey(self, key, intf, interactive = True):
        if instnum is not None and instnum.formatMap.has_key(len(key)):
            inum = instnum.InstNum(key)
            for name, path in inum.get_repos_dict().items():
                self.repopaths[name.lower()] = path
                log.info("Adding %s repo" % (path,))
        else:
            key = key.upper()
            # simple and stupid for now... if C is in the key, add Clustering
            # if V is in the key, add Virtualization. etc
            if key.find("C") != -1:
                self.repopaths["cluster"] = ["Cluster"]
                log.info("Adding Cluster option")
            if key.find("S") != -1:
                self.repopaths["clusterstorage"] = ["ClusterStorage"]
                log.info("Adding ClusterStorage option")
            if key.find("W") != -1:
                self.repopaths["workstation"] = ["Workstation"]
                log.info("Adding Workstation option")
            if key.find("V") != -1:
                self.repopaths["virt"] = ["VT"]
                log.info("Adding Virtualization option")

        log.info("repopaths is %s" %(self.repopaths,))

        self.installkey = key

    def __init__(self, expert):
	BaseInstallClass.__init__(self, expert)

        self.repopaths = { "base": [ "%s" %(productPath,) ] }
